<TS language="hr" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>Desni klik za uređivanje adresa i oznaka</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Dodajte novu adresu</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nova</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Kopiraj trenutno odabranu adresu u međuspremnik</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopiraj</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Zatvori</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Brisanje trenutno odabrane adrese s popisa.</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Izvoz podataka iz trenutnog lista u datoteku</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Izvozi</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>Iz&amp;briši</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Odaberi adresu na koju šalješ novac</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Odaberi adresu na koju primaš novac</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>&amp;Odaberi</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Adresa pošiljatelja</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Adresa primatelja</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Ovo su vaše Bitcoin adrese za slanje novca. Uvijek provjerite iznos i adresu primatelja prije slanja novca.</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. It is recommended to use a new receiving address for each transaction.</source>
        <translation>Ovo su vaše Bitcoin adrese za primanje novca. Preporučamo da koristite novu adresu za primanje za svaku transakciju.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;Kopiraj adresu</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Kopiraj i označi</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>Uredi</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Izvezi listu adresa</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Datoteka podataka odvojenih zarezima (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Izvoz neuspješan</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>Došlo je do pogreške kod spremanja liste adresa na %1. Molimo pokušajte ponovno.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Oznaka</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nema oznake)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Dijalog lozinke</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Unesite lozinku</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nova lozinka</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Ponovite novu lozinku</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Unesite novu lozinku za novčanik. &lt;br/&gt;Molimo Vas da koristite zaporku od &lt;b&gt;deset ili više slučajnih znakova&lt;/b&gt;, ili &lt;b&gt;osam ili više riječi.&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Šifriranje novčanika</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Ova operacija treba lozinku vašeg novčanika kako bi se novčanik otključao.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Otključaj novčanik</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Ova operacija treba lozinku vašeg novčanika kako bi se novčanik dešifrirao.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Dešifriranje novčanika.</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Promjena lozinke</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase to the wallet.</source>
        <translation>Unesite staru i novu lozinku za novčanik.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Potvrdi šifriranje novčanika</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation>Upozorenje: Ako šifrirate vaš novčanik i izgubite lozinku, &lt;b&gt;IZGUBIT ĆETE SVE SVOJE BITCOINE!&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Jeste li sigurni da želite šifrirati svoj novčanik?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Novčanik šifriran</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>VAŽNO: Sve prethodne pričuve vašeg novčanika trebale bi biti zamijenjene novo stvorenom, šifriranom datotekom novčanika. Zbog sigurnosnih razloga, prethodne pričuve nešifriranog novčanika će postati beskorisne čim počnete koristiti novi, šifrirani novčanik.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Šifriranje novčanika nije uspjelo</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Šifriranje novčanika nije uspjelo zbog interne pogreške. Vaš novčanik nije šifriran.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Priložene lozinke se ne podudaraju.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Otključavanje novčanika nije uspjelo</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Lozinka za dešifriranje novčanika nije točna.</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Dešifriranje novčanika nije uspjelo</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Lozinka novčanika je uspješno promijenjena.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Upozorenje: Caps Lock je uključen!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>P&amp;otpišite poruku...</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Usklađivanje s mrežom ...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Pregled</translation>
    </message>
    <message>
        <source>Node</source>
        <translation>Čvor</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Prikaži opći pregled novčanika</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Transakcije</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Pretraži povijest transakcija</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Izlaz</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Izlazak iz programa</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp;Više o %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Više o &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Prikaži informacije o Qt</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>Pos&amp;tavke...</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>Ši&amp;friraj novčanik...</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>Spremi &amp;kopiju novčanika...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>Promjena &amp;lozinke...</translation>
    </message>
    <message>
        <source>&amp;Sending addresses...</source>
        <translation>Adrese za &amp;slanje</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses...</source>
        <translation>Adrese za &amp;primanje</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>Otvori &amp;URI...</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>Re-indeksiranje blokova na disku...</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation>Slanje novca na bitcoin adresu</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>Napravite sigurnosnu kopiju novčanika na drugoj lokaciji</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Promijenite lozinku za šifriranje novčanika</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>Konzola za dijagnostiku</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Otvori konzolu za dijagnostiku</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Potvrdite poruku...</translation>
    </message>
    <message>
        <source>Bitcoin</source>
        <translation>Bitcoin</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Novčanik</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Pošalji</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>Pri&amp;mi</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>Po&amp;kaži / Sakrij</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>Prikaži ili sakrij glavni prozor</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation>Šifriranje privatnih ključeva koji u novčaniku</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation>Poruku potpišemo s bitcoin adresom, kako bi dokazali vlasništvo nad tom adresom</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation>Provjeravanje poruke, kao dokaz, da je potpisana navedenom bitcoin adresom</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datoteka</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Postavke</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoć</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Traka kartica</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation>Zatraži uplatu (stvara QR kod i bitcoin: URI adresu)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation>Prikaži popis korištenih adresa i oznaka za slanje novca</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation>Prikaži popis korištenih adresa i oznaka za primanje novca</translation>
    </message>
    <message>
        <source>Open a bitcoin: URI or payment request</source>
        <translation>Otvori bitcoin: URI adresu ili zahtjev za uplatu</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation>Opcije &amp;naredbene linije</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network</source>
        <translation><numerusform>%n aktivna veza na Bitcoin mrežu</numerusform><numerusform>%n aktivnih veza na Bitcoin mrežu</numerusform><numerusform>%n aktivnih veza na Bitcoin mrežu</numerusform></translation>
    </message>
    <message>
        <source>Indexing blocks on disk...</source>
        <translation>Indeksiram blokove na disku...</translation>
    </message>
    <message>
        <source>Processing blocks on disk...</source>
        <translation>Procesiram blokove na disku...</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation><numerusform>Obrađen %n blok povijesti transakcije.</numerusform><numerusform>Obrađeno %n bloka povijesti transakcije.</numerusform><numerusform>Obrađeno %n blokova povijesti transakcije.</numerusform></translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation>Zadnji primljeni blok je bio ustvaren prije %1.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation>Transakcije izvršene za tim blokom nisu još prikazane.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Greška</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Upozorenje</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informacija</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Ažurno</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation>%1 klijent</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Ažuriranje...</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation>Datum: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation>Iznos: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation>Vrsta: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation>Oznaka: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation>Adresa: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Poslana transakcija</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Dolazna transakcija</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation>Novčanik je &lt;b&gt;šifriran&lt;/b&gt; i trenutno &lt;b&gt;otključan&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Novčanik je &lt;b&gt;šifriran&lt;/b&gt; i trenutno &lt;b&gt;zaključan&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Coin Selection</source>
        <translation>Izbor ulaza transakcije</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Količina:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bajtova:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Iznos:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Naknada:</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Prah:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Vraćeno:</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation>Izaberi sve/ništa</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Iznos</translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation>Primljeno pod oznakom</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation>Primljeno na adresu</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Broj potvrda</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Potvrđeno</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopiraj adresu</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopiraj oznaku</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopiraj iznos</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Kopiraj ID transakcije</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>da</translation>
    </message>
    <message>
        <source>no</source>
        <translation>ne</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nema oznake)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Uredi adresu</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Oznaka</translation>
    </message>
    <message>
        <source>The label associated with this address list entry</source>
        <translation>Oznaka bitcoin adrese</translation>
    </message>
    <message>
        <source>The address associated with this address list entry. This can only be modified for sending addresses.</source>
        <translation>Bitcoin adresa. Izmjene adrese su moguće samo za adrese za slanje.</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Adresa</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Nova adresa za primanje</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Nova adresa za slanje</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Uredi adresu za primanje</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Uredi adresu za slanje</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Bitcoin address.</source>
        <translation>Upisana adresa "%1" nije valjana bitcoin adresa.</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>Upisana adresa "%1" je već u adresaru.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Ne mogu otključati novčanik.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Stvaranje novog ključa nije uspjelo.</translation>
    </message>
</context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>A new data directory will be created.</source>
        <translation>Stvoren će biti novi direktorij za podatke.</translation>
    </message>
    <message>
        <source>name</source>
        <translation>ime</translation>
    </message>
    <message>
        <source>Cannot create data directory here.</source>
        <translation>Nije moguće stvoriti direktorij za podatke na tom mjestu.</translation>
    </message>
</context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>verzija</translation>
    </message>
    <message>
        <source>(%1-bit)</source>
        <translation>(%1-bit)</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>Opcije programa u naredbenoj liniji</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Upotreba:</translation>
    </message>
    <message>
        <source>command-line options</source>
        <translation>opcije programa u naredbenoj liniji</translation>
    </message>
    <message>
        <source>Start minimized</source>
        <translation>Pokreni minimiziran</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>Dobrodošli</translation>
    </message>
    <message>
        <source>Bitcoin</source>
        <translation>Bitcoin</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Greška</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation>Oblik</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Posljednje vrijeme bloka</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Open URI</source>
        <translation>Otvori URI adresu</translation>
    </message>
    <message>
        <source>Open payment request from URI or file</source>
        <translation>Otvori zahtjev za plaćanje iz URI adrese ili datoteke</translation>
    </message>
    <message>
        <source>URI:</source>
        <translation>URI:</translation>
    </message>
    <message>
        <source>Select payment request file</source>
        <translation>Izaberi datoteku zahtjeva za plaćanje</translation>
    </message>
    <message>
        <source>Select payment request file to open</source>
        <translation>Izaberi datoteku zahtjeva za plaćanje</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Postavke</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Glavno</translation>
    </message>
    <message>
        <source>Size of &amp;database cache</source>
        <translation>Veličina predmemorije baze podataka</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>Number of script &amp;verification threads</source>
        <translation>Broj CPU niti za verifikaciju transakcija</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. IPv4: 127.0.0.1 / IPv6: ::1)</source>
        <translation>IP adresa proxy servera (npr. IPv4: 127.0.0.1 / IPv6: ::1)</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Exit in the menu.</source>
        <translation>Minimizirati aplikaciju umjesto zatvoriti, kada se zatvori prozor. Kada je ova opcija omogućena, aplikacija će biti zatvorena tek nakon odabira naredbe Izlaz u izborniku.</translation>
    </message>
    <message>
        <source>Reset all client options to default.</source>
        <translation>Nastavi sve postavke programa na početne vrijednosti.</translation>
    </message>
    <message>
        <source>&amp;Reset Options</source>
        <translation>Po&amp;nastavi postavke</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Mreža</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation>&amp;Novčanik</translation>
    </message>
    <message>
        <source>&amp;Spend unconfirmed change</source>
        <translation>&amp;Trošenje nepotvrđenih vraćenih iznosa</translation>
    </message>
    <message>
        <source>Automatically open the Bitcoin client port on the router. This only works when your router supports UPnP and it is enabled.</source>
        <translation>Automatski otvori port Bitcoin klijenta na ruteru. To radi samo ako ruter podržava UPnP i ako je omogućen.</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Mapiraj port koristeći &amp;UPnP</translation>
    </message>
    <message>
        <source>Proxy &amp;IP:</source>
        <translation>Proxy &amp;IP:</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Vrata:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Proxy vrata (npr. 9050)</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Prozor</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Prikaži samo ikonu u sistemskoj traci nakon minimiziranja prozora</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Minimiziraj u sistemsku traku umjesto u traku programa</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>M&amp;inimiziraj kod zatvaranja</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Prikaz</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>Jezi&amp;k sučelja:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;Jedinica za prikaz iznosa:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Izaberite željeni najmanji dio bitcoina koji će biti prikazan u sučelju i koji će se koristiti za plaćanje.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;U redu</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Odustani</translation>
    </message>
    <message>
        <source>default</source>
        <translation>standardne vrijednosti</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Greška</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>Priložena proxy adresa je nevažeća.</translation>
    </message>
</context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Oblik</translation>
    </message>
    <message>
        <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Bitcoin network after a connection is established, but this process has not completed yet.</source>
        <translation>Prikazani podatci mogu biti zastarjeli. Vaš novčanik se automatski sinkronizira s Bitcoin mrežom kada je veza uspostavljena, ali taj proces još nije završen.</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Ukupno:</translation>
    </message>
    </context>
<context>
    <name>PaymentServer</name>
    <message>
        <source>URI handling</source>
        <translation>URI upravljanje</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Sent</source>
        <translation>Poslano</translation>
    </message>
    <message>
        <source>Received</source>
        <translation>Primljeno</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Iznos</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>%1 and %2</source>
        <translation>%1 i %2</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>nepoznato</translation>
    </message>
</context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    <message>
        <source>&amp;Save Image...</source>
        <translation>&amp;Spremi sliku...</translation>
    </message>
    <message>
        <source>Save QR Code</source>
        <translation>Spremi QR kod</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>Verzija klijenta</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Informacije</translation>
    </message>
    <message>
        <source>Debug window</source>
        <translation>Konzola za dijagnostiku</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Mreža</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Ime</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Broj veza</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Lanac blokova</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Trenutni broj blokova</translation>
    </message>
    <message>
        <source>Received</source>
        <translation>Primljeno</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation>Poslano</translation>
    </message>
    <message>
        <source>Direction</source>
        <translation>Smjer</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Verzija</translation>
    </message>
    <message>
        <source>Connection Time</source>
        <translation>Trajanje veze</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Posljednje vrijeme bloka</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Otvori</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Konzola</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;Mrežni promet</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>Ukupno:</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Očisti konzolu</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Nepoznato</translation>
    </message>
</context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation>&amp;Iznos:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Oznaka:</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation>&amp;Poruka:</translation>
    </message>
    <message>
        <source>Clear all fields of the form.</source>
        <translation>Obriši sva polja</translation>
    </message>
    <message>
        <source>&amp;Request payment</source>
        <translation>&amp;Zatraži plaćanje</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Pokaži</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopiraj oznaku</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopiraj iznos</translation>
    </message>
</context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>QR Code</source>
        <translation>QR kôd</translation>
    </message>
    <message>
        <source>Copy &amp;URI</source>
        <translation>Kopiraj &amp;URI</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation>Kopiraj &amp;adresu</translation>
    </message>
    <message>
        <source>&amp;Save Image...</source>
        <translation>&amp;Spremi sliku...</translation>
    </message>
    <message>
        <source>URI</source>
        <translation>URI</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Iznos</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Oznaka</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Poruka</translation>
    </message>
    <message>
        <source>Resulting URI too long, try to reduce the text for label / message.</source>
        <translation>URI je predug, probajte skratiti tekst za naslov / poruku.</translation>
    </message>
    <message>
        <source>Error encoding URI into QR Code.</source>
        <translation>Greška kod kodiranja URI adrese u QR kod.</translation>
    </message>
</context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Oznaka</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Poruka</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nema oznake)</translation>
    </message>
    <message>
        <source>(no message)</source>
        <translation>(bez poruke)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Slanje novca</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Nedovoljna sredstva</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Količina:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bajtova:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Iznos:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Naknada:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Vraćeno:</translation>
    </message>
    <message>
        <source>Transaction Fee:</source>
        <translation>Naknada za transakciju:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Pošalji novce većem broju primatelja u jednoj transakciji</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>&amp;Dodaj primatelja</translation>
    </message>
    <message>
        <source>Clear all fields of the form.</source>
        <translation>Obriši sva polja</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Prah:</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Obriši &amp;sve</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>Stanje:</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Potvrdi akciju slanja</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>&amp;Pošalji</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopiraj iznos</translation>
    </message>
    <message>
        <source>or</source>
        <translation>ili</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Potvrdi slanje novca</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Iznos mora biti veći od 0.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>Iznos je veći od raspoložljivog stanja novčanika.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>Iznos je veći od stanja novčanika kad se doda naknada za transakcije od %1.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nema oznake)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>&amp;Iznos:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>&amp;Primatelj plaćanja:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Oznaka:</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Zalijepi adresu iz međuspremnika</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Poruka:</translation>
    </message>
    <message>
        <source>Pay To:</source>
        <translation>Primatelj plaćanja:</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Unesite oznaku za ovu adresu kako bi ju dodali u vaš adresar</translation>
    </message>
</context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Potpišite poruku</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Zalijepi adresu iz međuspremnika</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Upišite poruku koju želite potpisati ovdje</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Potpis</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>&amp;Potpišite poruku</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Obriši &amp;sve</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Potvrdite poruku</translation>
    </message>
    <message>
        <source>Verify &amp;Message</source>
        <translation>&amp;Potvrdite poruku</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>Otključavanje novčanika je otkazano.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Poruka je potpisana.</translation>
    </message>
    </context>
<context>
    <name>SplashScreen</name>
    <message>
        <source>[testnet]</source>
        <translation>[testnet]</translation>
    </message>
</context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Open until %1</source>
        <translation>Otvoren do %1</translation>
    </message>
    <message>
        <source>%1/offline</source>
        <translation>%1 nije dostupan</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/nepotvrđeno</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 potvrda</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>, još nije bio uspješno emitiran</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Izvor</translation>
    </message>
    <message>
        <source>Generated</source>
        <translation>Generiran</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Od</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>nepoznato</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Za</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>vlastita adresa</translation>
    </message>
    <message>
        <source>label</source>
        <translation>oznaka</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>Uplaćeno</translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>Nije prihvaćeno</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>Zaduženje</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Naknada za transakciju</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Neto iznos</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Poruka</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Komentar</translation>
    </message>
    <message>
        <source>Transaction ID</source>
        <translation>ID transakcije</translation>
    </message>
    <message>
        <source>Transaction</source>
        <translation>Transakcija</translation>
    </message>
    <message>
        <source>Inputs</source>
        <translation>Unosi</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Iznos</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Ovaj prozor prikazuje detaljni opis transakcije</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tip</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Oznaka</translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Otvoren do %1</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Potvrđen (%1 potvrda)</translation>
    </message>
    <message>
        <source>This block was not received by any other nodes and will probably not be accepted!</source>
        <translation>Ovaj blok nije bio primljen od strane bilo kojeg drugog čvora i vjerojatno neće biti prihvaćen!</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Generirano, ali nije prihvaćeno</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Primljeno s</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Primljeno od</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Poslano za</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Plaćanje samom sebi</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Rudareno</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation>(n/d)</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nema oznake)</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Status transakcije</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Datum i vrijeme kad je transakcija primljena</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Vrsta transakcije.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Iznos odbijen od ili dodan k saldu.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>All</source>
        <translation>Sve</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Danas</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Ovaj tjedan</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Ovaj mjesec</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Prošli mjesec</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Ove godine</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Raspon...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Primljeno s</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Poslano za</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>Samom sebi</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Rudareno</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Ostalo</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Min iznos</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopiraj adresu</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopiraj oznaku</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopiraj iznos</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Kopiraj ID transakcije</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Izmjeni oznaku</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>Prikaži detalje transakcije</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Datoteka podataka odvojenih zarezima (*.csv)</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Potvrđeno</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tip</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Oznaka</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <source>ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Izvoz neuspješan</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Raspon:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>za</translation>
    </message>
</context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Send Coins</source>
        <translation>Slanje novca</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Izvozi</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Izvoz podataka iz trenutnog lista u datoteku</translation>
    </message>
    <message>
        <source>Backup Wallet</source>
        <translation>Arhiviranje novčanika</translation>
    </message>
    <message>
        <source>Wallet Data (*.dat)</source>
        <translation>Podaci novčanika (*.dat)</translation>
    </message>
    <message>
        <source>Backup Failed</source>
        <translation>Arhiviranje nije uspjelo</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Options:</source>
        <translation>Postavke:</translation>
    </message>
    <message>
        <source>Specify data directory</source>
        <translation>Odaberi direktorij za datoteke</translation>
    </message>
    <message>
        <source>Specify your own public address</source>
        <translation>Odaberi vlastitu javnu adresu</translation>
    </message>
    <message>
        <source>Accept command line and JSON-RPC commands</source>
        <translation>Prihvati komande iz tekst moda i JSON-RPC</translation>
    </message>
    <message>
        <source>Run in the background as a daemon and accept commands</source>
        <translation>Izvršavaj u pozadini kao uslužnik i prihvaćaj komande</translation>
    </message>
    <message>
        <source>Bitcoin Core</source>
        <translation>Bitcoin Core</translation>
    </message>
    <message>
        <source>Block creation options:</source>
        <translation>Opcije za kreiranje bloka:</translation>
    </message>
    <message>
        <source>Error: Disk space is low!</source>
        <translation>Pogreška: Nema dovoljno prostora na disku!</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informacija</translation>
    </message>
    <message>
        <source>Send trace/debug info to console instead of debug.log file</source>
        <translation>Šalji trace/debug informacije na konzolu umjesto u debug.log datoteku</translation>
    </message>
    <message>
        <source>Username for JSON-RPC connections</source>
        <translation>Korisničko ime za JSON-RPC veze</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Upozorenje</translation>
    </message>
    <message>
        <source>Password for JSON-RPC connections</source>
        <translation>Lozinka za JSON-RPC veze</translation>
    </message>
    <message>
        <source>Execute command when the best block changes (%s in cmd is replaced by block hash)</source>
        <translation>Izvršite naredbu kada se najbolji blok promjeni (%s u cmd je zamjenjen sa block hash)</translation>
    </message>
    <message>
        <source>Allow DNS lookups for -addnode, -seednode and -connect</source>
        <translation>Dozvoli DNS upite za -addnode, -seednode i -connect</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Nedovoljna sredstva</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Učitavanje indeksa blokova...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Učitavanje novčanika...</translation>
    </message>
    <message>
        <source>Cannot downgrade wallet</source>
        <translation>Nije moguće novčanik vratiti na prijašnju verziju.</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Ponovno pretraživanje...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Učitavanje gotovo</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Greška</translation>
    </message>
</context>
</TS>